@@ -54,6 +54,8 @@ class PollVoteView(FormView):
             'POLL_ANONYMOUS_SESSION_AGE',
             0)
         
+        message = None
+        
         self.pk = kwargs.get('pk')
         self.form = PollVoteForm(request.POST)
         user = request.user
@@ -68,10 +70,16 @@ class PollVoteView(FormView):
             )
 
         if (user.is_authenticated() and poll.has_voted(user)) or (not user.is_authenticated() and ANONYMOUS_VOTING and request.session.get(session_key, False)):
+            message = getattr(
+                settings,
+                'POLL_MESSAGE_VOTE_ERROR_ALREADY_VOTED',
+                'You have already voted in this poll!')
+                
             messages.add_message(
                 request,
                 messages.WARNING,
-                'You have already voted in the poll.')
+                message)
+                
             return HttpResponseRedirect(request.path)
 
         if len(request.POST.getlist('choice')) > 0:
@@ -99,7 +107,12 @@ class PollVoteView(FormView):
                 request.session[session_key] = True
                 request.session.set_expiry(ANONYMOUS_SESSION_AGE)
             
-            messages.add_message(request, messages.SUCCESS, 'Vote was successful!')
+            message = getattr(
+                settings,
+                'POLL_MESSAGE_VOTE',
+                'Voted!')
+                
+            messages.add_message(request, messages.SUCCESS, message)
     
             return (
                 HttpResponseRedirect(
@@ -107,7 +120,12 @@ class PollVoteView(FormView):
                             kwargs={'pk': self.pk}))
             )
         else:
-            messages.add_message(request, messages.WARNING, 'Select a choice.')
+            message = getattr(
+                settings,
+                'POLL_MESSAGE_VOTE_ERROR_CHOICE_SELECTION',
+                'Select a choice!')
+                
+            messages.add_message(request, messages.WARNING, message)
             return HttpResponseRedirect(request.path)
 
     def get_context_data(self, *args, **kwargs):
@@ -150,7 +168,9 @@ class PollView(FormView):
 
     def post(self, request, *args, **kwargs):
         pk = kwargs.get('pk')
-
+        
+        message = None
+            
         if pk:
             instance = Poll.objects.get(pk=pk)
             if request.user != instance.user:
@@ -159,8 +179,17 @@ class PollView(FormView):
                         '%s?%s' %
                         (settings.LOGIN_URL, request.path))
                 )
+                
+            message = getattr(
+                settings,
+                'POLL_MESSAGE_UPDATE',
+                'Poll was updated!')
         else:
             instance = None
+            message = getattr(
+                settings,
+                'POLL_MESSAGE_ADD',
+                'Poll was added!')
 
         data = request.POST
 
@@ -169,6 +198,9 @@ class PollView(FormView):
         if form.is_valid() and formset.is_valid():
             form.save()
             formset.save()
+            
+            messages.add_message(request, messages.SUCCESS, message)
+            
             return (
                 HttpResponseRedirect(
                     reverse('poll_vote', kwargs={'pk': form.instance.pk}))
